@@ -31,3 +31,7 @@ void WrSink::setPlugin(WrPlugin *plugin) {
 QImage WrSink::getImage() {
     return image;
 }
+
+void WrSink::emitIsReady() {
+    emit isReady();
+}
